"""Photo Import.

A tool for importing photos from one directory into a hierarchical folder
structure in another directory based on the EXIF data of the photos.

Usage:
    photo-import SOURCE DESTINATION

Arguments:
    SOURCE      photo to be imported
    DESTINATION directory to move photos into

Options:
    -h --help       Show this help.
    -v --version    Show version.

"""
import os

from docopt import docopt

from photoimport import __version__
from photoimport.folders import FolderCreator
from photoimport.photos import ExifReader


def main():
    arguments = docopt(__doc__, version=__version__)
    reader = ExifReader(os.path.dirname(arguments['SOURCE']))
    creator = FolderCreator(arguments['DESTINATION'])

    date = reader.extract_date(os.path.basename(arguments['SOURCE']))
    creator.create_folder(date)
    creator.move_file(arguments['SOURCE'], date)



import os
import shutil


class FolderCreator:

    def __init__(self, base_dir):
        self._base_dir = base_dir

    def create_folder(self, date):
        path = self._build_path(date)
        os.makedirs(path, exist_ok=True)

    def move_file(self, file, date):
        shutil.move(file, self._build_path(date))

    def _build_path(self, date):
        year = '{:04d}'.format(date.year)
        month = '{:02d}'.format(date.month)
        day = '{:02d}'.format(date.day)
        path = os.path.join(self._base_dir, year, month, day)
        return path



import os
from datetime import datetime

from exif import Image


class ExifReader:

    def __init__(self, base_dir):
        self._base_dir = base_dir

    def extract_date(self, filename):
        path = os.path.join(self._base_dir, filename)
        with open(path, 'rb') as image_file:
            image = Image(image_file)
            return datetime.strptime(image.datetime_original, '%Y:%m:%d %H:%M:%S').date()



import re

from setuptools import setup

version = re.search(
    '^__version__\s*=\s*"(.*)"',
    open('photoimport/__init__.py').read(),
    re.M
).group(1)

with open("README.rst", "rb") as f:
    readme = f.read().decode("utf-8")

setup(
    name="photo-import",
    packages=["photoimport"],
    entry_points={
        "console_scripts": ['photo-import = photoimport.command:main']
    },
    version=version,
    description="Application to import photos into a hierarchical structure based on the EXIF data of the photos.",
    long_description=readme,
    long_description_content_type="text/x-rst",
    author="Edd Armitage",
    author_email="edward.armitage@gmail.com",
    url="https://gitlab.com/eddarmitage/photo-import",
    license="MIT",
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: MIT License',
        'Environment :: Console',
        'Natural Language :: English',
        'Operating System :: MacOS :: MacOS X',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    python_requires='>=3.4',
    install_requires=["exif", "docopt"],
    setup_requires=["pytest-runner"],
    tests_require=["pytest", "pyfakefs"],
    extras_require={
        'python_version<=3.7': ['backports-datetime-fromisoformat==1.0.0', ],
    },
)
